@@ -11,7 +11,7 @@ source env/$VENV/bin/activate
 pip install dist/rawpy*cp${PYVER}*macosx*${PYTHON_ARCH}*.whl
 
 # Test installed rawpy
-pip install -r dev-requirements.txt
+pip install -r dev-requirements.txt "numpy==${NUMPY_VERSION}"
 mkdir tmp_for_test
 pushd tmp_for_test
 python -u -m pytest -v -s ../test
